# LemonTCG (WORK IN PROGRESS)
A python TCG library tailored to a cool idea I had, designed to be easily extendable with new cards and interactions.
It will eventually serve the game logic for my TCG client and server.